@@ -115,11 +115,7 @@ def SortDictOfDict(Dict, key, reverseOrder=False):
     reverseOrder = True
 
     >> {'b': {'time_stamp': 50}, 'a': {'time_stamp': '100'}, 'c': {'time_stamp': 150}}
-
     """
-
-
-
     if not collections:
         raise ImportError("collections was not found during boot, Install collections to use this function")
     r = collections.OrderedDict(sorted(Dict.items(), key=lambda t:t[1][key], reverse=reverseOrder))
@@ -138,7 +134,7 @@ def DictToArgs(Dict):
     """
     args = []
     for item in Dict:
-        args.append(item + "=" + Dict[item])
+        args.append(item + "=" + str(Dict[item]))
     args = "&".join(args)
     return "?" + args
 
